@@ -6,7 +6,7 @@ from typing import Dict, Optional, Tuple, Union
 from urllib.parse import urlencode
 
 from recce.exceptions import RecceException
-from recce.pull_request import fetch_pr_metadata
+from recce.pull_request import PullRequestInfo, fetch_pr_metadata
 from recce.util.io import SupportedFileTypes, file_io_factory
 from recce.util.recce_cloud import PresignedUrlMethod, RecceCloud, RecceCloudException
 
@@ -210,6 +210,7 @@ class CloudStateLoader(RecceStateLoader):
         logger.debug(f"Getting session {self.session_id}")
         session = self.recce_cloud.get_session(self.session_id)
 
+        pr_url = session.get("pr_link")
         org_id = session.get("org_id")
         project_id = session.get("project_id")
 
@@ -231,6 +232,13 @@ class CloudStateLoader(RecceStateLoader):
             logger.debug(f"No existing recce_state found, creating new state: {e}")
             state = RecceState()
 
+        if pr_url:
+            pr_id = pr_url.rstrip("/").split("/")[-1]
+            pull_request = PullRequestInfo(id=pr_id, url=pr_url)
+            self.pr_info = pull_request
+            if state.pull_request is None:
+                state.pull_request = pull_request
+
         # Set artifacts regardless of whether we loaded existing state
         state.artifacts.base = base_artifacts
         state.artifacts.current = current_artifacts
@@ -411,6 +419,9 @@ class CloudStateLoader(RecceStateLoader):
 
         if message:
             logger.warning(message)
+        else:
+            # Notify Recce Cloud that the state has been uploaded if upload is successful
+            self.recce_cloud.post_recce_state_uploaded_by_session_id(org_id, project_id, self.session_id)
         return message, None
 
     def _upload_state_to_url(
@@ -581,7 +592,7 @@ class RecceCloudStateManager:
 
     def _purge_state_from_recce_cloud(self) -> (bool, str):
         try:
-            RecceCloud(token=self.github_token).purge_artifacts(self.pr_info)
+            RecceCloud(token=self.github_token).purge_artifacts(self.pr_info.repository, pr_id=self.pr_info.id)
         except RecceCloudException as e:
             return False, e.reason
         return True, None
